pub fn interp1d<S: Scalar>(
x: &[S],
y: &[S],
method: Interp1dMethod,
) -> Result<Box<dyn Interpolant<S>>, InterpError>Expand description
Convenience: create an interpolant from data using the specified method.
pub fn interp1d<S: Scalar>(
x: &[S],
y: &[S],
method: Interp1dMethod,
) -> Result<Box<dyn Interpolant<S>>, InterpError>Convenience: create an interpolant from data using the specified method.